# Copyright 2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Smoke tests for the subcommands."""

import unittest

from lpsetup.cli import (
    main,
    SUBCOMMANDS,
    )

from lpsetup.tests.utils import (
    capture_output,
    test_template_dir,
    )


class SmokeTest(unittest.TestCase):
    """Tests which are intended to do a quick check for broken subcommands."""

    def test_subcommand_smoke_via_help(self):
        # Perform a basic smoke test by running each subcommand's --help
        # function and verify that a non-error exit code is returned.
        for name, _ in SUBCOMMANDS:
            self.assertEqual(main([name, '--help']), 0)

    def test_subcommand_smoke_via_dry_run(self):
        # Perform a basic smoke test by running each subcommand's dry run
        # and verify that a non-error exit code is returned.
        required_args = ['-f', 'Example User', '-E', 'email@example.com']
        name_args_map = {
            'init-target': required_args,
            'init-lxc': required_args,
            'init-repo': [],
            'install-lxc': required_args,
            'update': [test_template_dir],
            }
        warning = 'This command will perform the following actions:'
        for name, args in name_args_map.items():
            with capture_output() as output:
                retcode = main([name, '--dry-run'] + args)
            self.assertFalse(retcode)
            # Ensure subcommand description is printed to stdout.
            self.assertIn(warning, output.getvalue())
